==> rosegarden-trinity_3.5.13.2.orig.tar.xz: rosegarden-trinity-3.5.13.2/src/gui/editors/segment/ControlParameterItem.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_CONTROLPARAMETERITEM_H_
#define _RG_CONTROLPARAMETERITEM_H_

#include <tqstring.h>
#include <klistview.h>


namespace Rosegarden
{


class ControlParameterItem : public KListViewItem
{
public:
    ControlParameterItem(int id,
                         TQListView *parent,
                         TQString str1,
                         TQString str2,
                         TQString str3,
                         TQString str4,
                         TQString str5,
                         TQString str6,
                         TQString str7,
                         TQString str8,
                         TQString str9):
        KListViewItem(parent, str1, str2, str3, str4, str5, str6, str7, str8),
        m_id(id) { setText(8, str9); }

    int getId() const { return m_id; }

protected:

    int     m_id;
    TQString m_string9;
};


}

#endif

==> rosegarden-trinity-14.0.7.tar.xz: rosegarden-trinity-14.0.7/src/gui/editors/segment/ControlParameterItem.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_CONTROLPARAMETERITEM_H_
#define _RG_CONTROLPARAMETERITEM_H_

#include <tqstring.h>
#include <tdelistview.h>


namespace Rosegarden
{


class ControlParameterItem : public TDEListViewItem
{
public:
    ControlParameterItem(int id,
                         TQListView *parent,
                         TQString str1,
                         TQString str2,
                         TQString str3,
                         TQString str4,
                         TQString str5,
                         TQString str6,
                         TQString str7,
                         TQString str8,
                         TQString str9):
        TDEListViewItem(parent, str1, str2, str3, str4, str5, str6, str7, str8),
        m_id(id) { setText(8, str9); }

    int getId() const { return m_id; }

protected:

    int     m_id;
    TQString m_string9;
};


}

#endif
